@@ -1,24 +1,31 @@
 /*
- * Copyright (C) 1996-2017 The Squid Software Foundation and contributors
+ * digest_common.h
+ *
+ * AUTHOR: Robert Collins.
  *
- * Squid software is distributed under GPLv2+ license and includes
- * contributions from numerous individuals and organizations.
- * Please see the COPYING and CONTRIBUTORS files for details.
- */
-
-/*
  * Digest helper API details.
+ *
+ * Copyright (c) 2003  Robert Collins  <robertc@squid-cache.org>
  */
 
 #ifndef SQUID_DIGEST_COMMON_H_
 #define SQUID_DIGEST_COMMON_H_
 
-#include <cctype>
-#include <cstdlib>
-#include <cstring>
+#if HAVE_STDIO_H
+#include <stdio.h>
+#endif
+#if HAVE_STDLIB_H
+#include <stdlib.h>
+#endif
+#if HAVE_CTYPE_H
+#include <ctype.h>
+#endif
 #if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
+#if HAVE_STRING_H
+#include <string.h>
+#endif
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
@@ -29,12 +36,11 @@
 #include <crypt.h>
 #endif
 
+#include "util.h"
 #include "hash.h"
 #include "rfc2617.h"
-#include "util.h"
 
 typedef struct _request_data {
-    int channelId;
     char *user;
     char *realm;
     char *password;
@@ -52,4 +58,3 @@ typedef void HandleArguments(int, char **);
 typedef void HHA1Creator(RequestData *);
 
 #endif /* SQUID_DIGEST_COMMON_H_ */
-
